pub enum DydxOrderType {
Limit,
Market,
StopLimit,
StopMarket,
TakeProfitLimit,
TakeProfitMarket,
TrailingStop,
}Expand description
dYdX order type.
Variants
Limit
Limit order with specified price.
Market
Market order (executed at best available price).
StopLimit
Stop-limit order (triggered at stop price, executed as limit).
StopMarket
Stop-market order (triggered at stop price, executed as market).
TakeProfitLimit
Take-profit order (limit).
TakeProfitMarket
Take-profit order (market).
TrailingStop
Trailing stop order (parsing only, not supported for submission).
Implementations
Sourceimpl DydxOrderType
impl DydxOrderType
Sourcepub fn try_from_order_type(value: OrderType) -> Result<Self>
pub fn try_from_order_type(value: OrderType) -> Result<Self>
Tries to convert from Nautilus OrderType.
Errors
Returns an error if the order type is not supported by dYdX.
Sourcepub const fn is_conditional(&self) -> bool
pub const fn is_conditional(&self) -> bool
Returns true if this is a conditional order type.
Sourcepub const fn condition_type(&self) -> DydxConditionType
pub const fn condition_type(&self) -> DydxConditionType
Returns the condition type for this order type.
Sourcepub const fn is_market_execution(&self) -> bool
pub const fn is_market_execution(&self) -> bool
Returns true if this order type should execute as market.